*   Title:  SMALL CHARGED SPHERE:  Lorentz force
*           F(mu,nu)*U(nu) singular orders
*           comparison to Schoonschip
*    File:  lfsing-ck.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  July 9, 2012
* Revised:  July 9,10,28,29, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  lfsing from lfsing.sav
*  Output:  none
*
* This program loads the output lfsing of lfsing.sav and
* checks it against Schoonschip results pasted from lf.out.

*** DECLARATIONS

off statistics;

S eps;
S c,snorm;
V u,a,j,n;
T d1y,d2y,d3y,d1u,d2u,d1a;
T eta;
I mu;

S norm,p;
I Naa;

Load lfsing.sav;

*** MODULES

* NeXT Schoonschip output, May 12, 1993.
* D1..., D2..., D3... replaced by d1..., d2..., d3... 28-Jul-12
* Note that this lacks a factor 1/c compared to lfsing.

L f(mu) = 
 + a(mu)*eps^-1
  * ( - 1/2*c^-1*norm^-1 )
 
 + d1y(Naa,n)*eta(mu,n)*d1y(u,n)*d1u(Naa,n)*eps^-1
  * ( 3*c^-1*norm^-5 )
 
 + d1y(Naa,n)*eta(mu,n)*d2y(Naa,n,n)*eps^-1
  * ( - 3/2*c*norm^-5 )
 
 + d1y(u,n)*d1y(u,n)*a(mu)*eps^-1
  * ( - 1/2*c^-3*norm^-3 )
 
 + d1y(u,n)*d1u(mu,n)*eps^-1
  * ( c^-1*norm^-3 )
 
 + d2y(mu,n,n)*eps^-1
  * ( - 1/2*c*norm^-3 )
 
 + d2y(u,n,n)*u(mu)*eps^-1
  * ( 1/2*c^-1*norm^-3 )
 
 + eta(mu,n)*eps^-2
  * ( - c*norm^-3 )
 
 + eta(mu,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*eps^-1
  * ( - 3/2*c^-3*norm^-5 )
 
 + eta(mu,n)*d1y(u,n)*d2y(u,n,n)*eps^-1
  * ( 3/2*c^-1*norm^-5 )
 
 + eta(mu,n)*d1y(a,n)*eps^-1
  * ( 1/2*c^-1*norm^-3 ) + 0;

id norm = snorm;
id norm^p? = snorm^p;
sum Naa;
.sort

Hide f;
G diff = lfsing(mu) - f(mu)/c;
b eps,snorm;
print;
.end
